Learn R Programming

SNPknock (version 0.8.2)

assemble_pEmit_phased: Compute the haplotype emission distributions based on the fastPHASE HMM

Description

Compute the haplotype emission distributions based on the fastPHASE HMM

Usage

assemble_pEmit_phased(theta)

Arguments